#[non_exhaustive]pub struct ApplicationDpuSizes {
pub application_runtime_id: Option<String>,
pub supported_dpu_sizes: Option<Vec<i32>>,
}Expand description
Contains the application runtime IDs and their supported DPU sizes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.application_runtime_id: Option<String>The name of the supported application runtime (for example, Athena notebook version 1).
supported_dpu_sizes: Option<Vec<i32>>A list of the supported DPU sizes that the application runtime supports.
Implementations
Sourceimpl ApplicationDpuSizes
impl ApplicationDpuSizes
Sourcepub fn application_runtime_id(&self) -> Option<&str>
pub fn application_runtime_id(&self) -> Option<&str>
The name of the supported application runtime (for example, Athena notebook version 1).
Sourcepub fn supported_dpu_sizes(&self) -> &[i32]
pub fn supported_dpu_sizes(&self) -> &[i32]
A list of the supported DPU sizes that the application runtime supports.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .supported_dpu_sizes.is_none().
Sourceimpl ApplicationDpuSizes
impl ApplicationDpuSizes
Sourcepub fn builder() -> ApplicationDpuSizesBuilder
pub fn builder() -> ApplicationDpuSizesBuilder
Creates a new builder-style object to manufacture ApplicationDpuSizes.