#[non_exhaustive]pub struct CapacityAllocation {
pub status: CapacityAllocationStatus,
pub status_message: Option<String>,
pub request_time: DateTime,
pub request_completion_time: Option<DateTime>,
}Expand description
Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: CapacityAllocationStatusThe status of the capacity allocation.
status_message: Option<String>The status message of the capacity allocation.
request_time: DateTimeThe time when the capacity allocation was requested.
request_completion_time: Option<DateTime>The time when the capacity allocation request was completed.
Implementations
Sourceimpl CapacityAllocation
impl CapacityAllocation
Sourcepub fn status(&self) -> &CapacityAllocationStatus
pub fn status(&self) -> &CapacityAllocationStatus
The status of the capacity allocation.
Sourcepub fn status_message(&self) -> Option<&str>
pub fn status_message(&self) -> Option<&str>
The status message of the capacity allocation.
Sourcepub fn request_time(&self) -> &DateTime
pub fn request_time(&self) -> &DateTime
The time when the capacity allocation was requested.
Sourcepub fn request_completion_time(&self) -> Option<&DateTime>
pub fn request_completion_time(&self) -> Option<&DateTime>
The time when the capacity allocation request was completed.
Sourceimpl CapacityAllocation
impl CapacityAllocation
Sourcepub fn builder() -> CapacityAllocationBuilder
pub fn builder() -> CapacityAllocationBuilder
Creates a new builder-style object to manufacture CapacityAllocation.