#[non_exhaustive]pub struct CapacityReservation {
pub name: String,
pub status: CapacityReservationStatus,
pub target_dpus: i32,
pub allocated_dpus: i32,
pub last_allocation: Option<CapacityAllocation>,
pub last_successful_allocation_time: Option<DateTime>,
pub creation_time: DateTime,
}Expand description
A reservation for a specified number of data processing units (DPUs). When a reservation is initially created, it has no DPUs. Athena allocates DPUs until the allocated amount equals the requested amount.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringThe name of the capacity reservation.
status: CapacityReservationStatusThe status of the capacity reservation.
target_dpus: i32The number of data processing units requested.
allocated_dpus: i32The number of data processing units currently allocated.
last_allocation: Option<CapacityAllocation>Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
last_successful_allocation_time: Option<DateTime>The time of the most recent capacity allocation that succeeded.
creation_time: DateTimeThe time in UTC epoch millis when the capacity reservation was created.
Implementations
Sourceimpl CapacityReservation
impl CapacityReservation
Sourcepub fn status(&self) -> &CapacityReservationStatus
pub fn status(&self) -> &CapacityReservationStatus
The status of the capacity reservation.
Sourcepub fn target_dpus(&self) -> i32
pub fn target_dpus(&self) -> i32
The number of data processing units requested.
Sourcepub fn allocated_dpus(&self) -> i32
pub fn allocated_dpus(&self) -> i32
The number of data processing units currently allocated.
Sourcepub fn last_allocation(&self) -> Option<&CapacityAllocation>
pub fn last_allocation(&self) -> Option<&CapacityAllocation>
Contains the submission time of a single allocation request for a capacity reservation and the most recent status of the attempted allocation.
Sourcepub fn last_successful_allocation_time(&self) -> Option<&DateTime>
pub fn last_successful_allocation_time(&self) -> Option<&DateTime>
The time of the most recent capacity allocation that succeeded.
Sourcepub fn creation_time(&self) -> &DateTime
pub fn creation_time(&self) -> &DateTime
The time in UTC epoch millis when the capacity reservation was created.
Sourceimpl CapacityReservation
impl CapacityReservation
Sourcepub fn builder() -> CapacityReservationBuilder
pub fn builder() -> CapacityReservationBuilder
Creates a new builder-style object to manufacture CapacityReservation.