#[non_exhaustive]pub struct Classification {
pub name: Option<String>,
pub properties: Option<HashMap<String, String>>,
}Expand description
A classification refers to a set of specific configurations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the configuration classification.
properties: Option<HashMap<String, String>>A set of properties specified within a configuration classification.
Implementations
Sourceimpl Classification
impl Classification
Sourcepub fn builder() -> ClassificationBuilder
pub fn builder() -> ClassificationBuilder
Creates a new builder-style object to manufacture Classification.