#[non_exhaustive]pub struct CloudWatchLoggingConfiguration {
pub enabled: bool,
pub log_group: Option<String>,
pub log_stream_name_prefix: Option<String>,
pub log_types: Option<HashMap<String, Vec<String>>>,
}Expand description
Configuration settings for delivering logs to Amazon CloudWatch log groups.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolEnables CloudWatch logging.
log_group: Option<String>The name of the log group in Amazon CloudWatch Logs where you want to publish your logs.
log_stream_name_prefix: Option<String>Prefix for the CloudWatch log stream name.
log_types: Option<HashMap<String, Vec<String>>>The types of logs that you want to publish to CloudWatch.
Implementations
Sourceimpl CloudWatchLoggingConfiguration
impl CloudWatchLoggingConfiguration
Sourceimpl CloudWatchLoggingConfiguration
impl CloudWatchLoggingConfiguration
Sourcepub fn builder() -> CloudWatchLoggingConfigurationBuilder
pub fn builder() -> CloudWatchLoggingConfigurationBuilder
Creates a new builder-style object to manufacture CloudWatchLoggingConfiguration.