ColumnInfo

Struct ColumnInfo 

#[non_exhaustive]
pub struct ColumnInfo { pub catalog_name: Option<String>, pub schema_name: Option<String>, pub table_name: Option<String>, pub name: String, pub label: Option<String>, pub type: String, pub precision: i32, pub scale: i32, pub nullable: Option<ColumnNullable>, pub case_sensitive: bool, }
Information about the columns in a query execution result.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
catalog_name: Option<String>

The catalog to which the query results belong.

schema_name: Option<String>

The schema name (database name) to which the query results belong.

table_name: Option<String>

The table name for the query results.

name: String

The name of the column.

label: Option<String>

A column label.

type: String

The data type of the column.

precision: i32

For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.

scale: i32

For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.

nullable: Option<ColumnNullable>

Unsupported constraint. This value always shows as UNKNOWN.

case_sensitive: bool

Indicates whether values in the column are case-sensitive.

Implementations

Source

impl ColumnInfo

pub fn catalog_name(&self) -> Option<&str>

The catalog to which the query results belong.

pub fn schema_name(&self) -> Option<&str>

The schema name (database name) to which the query results belong.

pub fn table_name(&self) -> Option<&str>

The table name for the query results.

pub fn name(&self) -> &str

The name of the column.

pub fn label(&self) -> Option<&str>

A column label.

pub fn type(&self) -> &str

The data type of the column.

pub fn precision(&self) -> i32

For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.

pub fn scale(&self) -> i32

For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.

pub fn nullable(&self) -> Option<&ColumnNullable>

Unsupported constraint. This value always shows as UNKNOWN.

pub fn case_sensitive(&self) -> bool

Indicates whether values in the column are case-sensitive.

Source

impl ColumnInfo

pub fn builder() -> ColumnInfoBuilder

Creates a new builder-style object to manufacture ColumnInfo.