DataCatalogSummary

Struct DataCatalogSummary 

#[non_exhaustive]
pub struct DataCatalogSummary { pub catalog_name: Option<String>, pub type: Option<DataCatalogType>, pub status: Option<DataCatalogStatus>, pub connection_type: Option<ConnectionType>, pub error: Option<String>, }
The summary information for the data catalog, which includes its name and type.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
catalog_name: Option<String>

The name of the data catalog. The catalog name is unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.

type: Option<DataCatalogType>

The data catalog type.

status: Option<DataCatalogStatus>

The status of the creation or deletion of the data catalog.

  • The LAMBDA, GLUE, and HIVE data catalog types are created synchronously. Their status is either CREATE_COMPLETE or CREATE_FAILED.

  • The FEDERATED data catalog type is created asynchronously.

Data catalog creation status:

  • CREATE_IN_PROGRESS: Federated data catalog creation in progress.

  • CREATE_COMPLETE: Data catalog creation complete.

  • CREATE_FAILED: Data catalog could not be created.

  • CREATE_FAILED_CLEANUP_IN_PROGRESS: Federated data catalog creation failed and is being removed.

  • CREATE_FAILED_CLEANUP_COMPLETE: Federated data catalog creation failed and was removed.

  • CREATE_FAILED_CLEANUP_FAILED: Federated data catalog creation failed but could not be removed.

Data catalog deletion status:

  • DELETE_IN_PROGRESS: Federated data catalog deletion in progress.

  • DELETE_COMPLETE: Federated data catalog deleted.

  • DELETE_FAILED: Federated data catalog could not be deleted.

connection_type: Option<ConnectionType>

The type of connection for a FEDERATED data catalog (for example, REDSHIFT, MYSQL, or SQLSERVER). For information about individual connectors, see Available data source connectors.

error: Option<String>

Text of the error that occurred during data catalog creation or deletion.

Implementations

Source

impl DataCatalogSummary

pub fn catalog_name(&self) -> Option<&str>

The name of the data catalog. The catalog name is unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.

pub fn type(&self) -> Option<&DataCatalogType>

The data catalog type.

pub fn status(&self) -> Option<&DataCatalogStatus>

The status of the creation or deletion of the data catalog.

  • The LAMBDA, GLUE, and HIVE data catalog types are created synchronously. Their status is either CREATE_COMPLETE or CREATE_FAILED.

  • The FEDERATED data catalog type is created asynchronously.

Data catalog creation status:

  • CREATE_IN_PROGRESS: Federated data catalog creation in progress.

  • CREATE_COMPLETE: Data catalog creation complete.

  • CREATE_FAILED: Data catalog could not be created.

  • CREATE_FAILED_CLEANUP_IN_PROGRESS: Federated data catalog creation failed and is being removed.

  • CREATE_FAILED_CLEANUP_COMPLETE: Federated data catalog creation failed and was removed.

  • CREATE_FAILED_CLEANUP_FAILED: Federated data catalog creation failed but could not be removed.

Data catalog deletion status:

  • DELETE_IN_PROGRESS: Federated data catalog deletion in progress.

  • DELETE_COMPLETE: Federated data catalog deleted.

  • DELETE_FAILED: Federated data catalog could not be deleted.

pub fn connection_type(&self) -> Option<&ConnectionType>

The type of connection for a FEDERATED data catalog (for example, REDSHIFT, MYSQL, or SQLSERVER). For information about individual connectors, see Available data source connectors.

pub fn error(&self) -> Option<&str>

Text of the error that occurred during data catalog creation or deletion.

Source

impl DataCatalogSummary

pub fn builder() -> DataCatalogSummaryBuilder

Creates a new builder-style object to manufacture DataCatalogSummary.