#[non_exhaustive]pub struct EngineConfiguration {
pub coordinator_dpu_size: Option<i32>,
pub max_concurrent_dpus: i32,
pub default_executor_dpu_size: Option<i32>,
pub additional_configs: Option<HashMap<String, String>>,
pub spark_properties: Option<HashMap<String, String>>,
pub classifications: Option<Vec<Classification>>,
}Expand description
The engine configuration for the workgroup, which includes the minimum/maximum number of Data Processing Units (DPU) that queries should use when running in provisioned capacity. If not specified, Athena uses default values (Default value for min is 4 and for max is Minimum of 124 and allocated DPUs).
To specify DPU values for PC queries the WG containing EngineConfiguration should have the following values: The name of the Classifications should be athena-query-engine-properties, with the only allowed properties as max-dpu-count and min-dpu-count.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.coordinator_dpu_size: Option<i32>The number of DPUs to use for the coordinator. A coordinator is a special executor that orchestrates processing work and manages other executors in a notebook session. The default is 1.
max_concurrent_dpus: i32The maximum number of DPUs that can run concurrently.
default_executor_dpu_size: Option<i32>The default number of DPUs to use for executors. An executor is the smallest unit of compute that a notebook session can request from Athena. The default is 1.
additional_configs: Option<HashMap<String, String>>Contains additional notebook engine MAP parameter mappings in the form of key-value pairs. To specify an Athena notebook that the Jupyter server will download and serve, specify a value for the StartSessionRequest$NotebookVersion field, and then add a key named NotebookId to AdditionalConfigs that has the value of the Athena notebook ID.
spark_properties: Option<HashMap<String, String>>Specifies custom jar files and Spark properties for use cases like cluster encryption, table formats, and general Spark tuning.
classifications: Option<Vec<Classification>>The configuration classifications that can be specified for the engine.
Implementations
Sourceimpl EngineConfiguration
impl EngineConfiguration
Sourcepub fn coordinator_dpu_size(&self) -> Option<i32>
pub fn coordinator_dpu_size(&self) -> Option<i32>
The number of DPUs to use for the coordinator. A coordinator is a special executor that orchestrates processing work and manages other executors in a notebook session. The default is 1.
Sourcepub fn max_concurrent_dpus(&self) -> i32
pub fn max_concurrent_dpus(&self) -> i32
The maximum number of DPUs that can run concurrently.
Sourcepub fn default_executor_dpu_size(&self) -> Option<i32>
pub fn default_executor_dpu_size(&self) -> Option<i32>
The default number of DPUs to use for executors. An executor is the smallest unit of compute that a notebook session can request from Athena. The default is 1.
Sourcepub fn additional_configs(&self) -> Option<&HashMap<String, String>>
pub fn additional_configs(&self) -> Option<&HashMap<String, String>>
Contains additional notebook engine MAP parameter mappings in the form of key-value pairs. To specify an Athena notebook that the Jupyter server will download and serve, specify a value for the StartSessionRequest$NotebookVersion field, and then add a key named NotebookId to AdditionalConfigs that has the value of the Athena notebook ID.
Sourcepub fn spark_properties(&self) -> Option<&HashMap<String, String>>
pub fn spark_properties(&self) -> Option<&HashMap<String, String>>
Specifies custom jar files and Spark properties for use cases like cluster encryption, table formats, and general Spark tuning.
Sourcepub fn classifications(&self) -> &[Classification]
pub fn classifications(&self) -> &[Classification]
The configuration classifications that can be specified for the engine.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .classifications.is_none().
Sourceimpl EngineConfiguration
impl EngineConfiguration
Sourcepub fn builder() -> EngineConfigurationBuilder
pub fn builder() -> EngineConfigurationBuilder
Creates a new builder-style object to manufacture EngineConfiguration.