ExecutorsSummary

Struct ExecutorsSummary 

#[non_exhaustive]
pub struct ExecutorsSummary { pub executor_id: String, pub executor_type: Option<ExecutorType>, pub start_date_time: Option<i64>, pub termination_date_time: Option<i64>, pub executor_state: Option<ExecutorState>, pub executor_size: Option<i64>, }
Contains summary information about an executor.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
executor_id: String

The UUID of the executor.

executor_type: Option<ExecutorType>

The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).

start_date_time: Option<i64>

The date and time that the executor started.

termination_date_time: Option<i64>

The date and time that the executor was terminated.

executor_state: Option<ExecutorState>

The processing state of the executor. A description of each state follows.

CREATING - The executor is being started, including acquiring resources.

CREATED - The executor has been started.

REGISTERED - The executor has been registered.

TERMINATING - The executor is in the process of shutting down.

TERMINATED - The executor is no longer running.

FAILED - Due to a failure, the executor is no longer running.

executor_size: Option<i64>

The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.

Implementations

Source

impl ExecutorsSummary

pub fn executor_id(&self) -> &str

The UUID of the executor.

pub fn executor_type(&self) -> Option<&ExecutorType>

The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).

pub fn start_date_time(&self) -> Option<i64>

The date and time that the executor started.

pub fn termination_date_time(&self) -> Option<i64>

The date and time that the executor was terminated.

pub fn executor_state(&self) -> Option<&ExecutorState>

The processing state of the executor. A description of each state follows.

CREATING - The executor is being started, including acquiring resources.

CREATED - The executor has been started.

REGISTERED - The executor has been registered.

TERMINATING - The executor is in the process of shutting down.

TERMINATED - The executor is no longer running.

FAILED - Due to a failure, the executor is no longer running.

pub fn executor_size(&self) -> Option<i64>

The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.

Source

impl ExecutorsSummary

pub fn builder() -> ExecutorsSummaryBuilder

Creates a new builder-style object to manufacture ExecutorsSummary.