#[non_exhaustive]pub struct ManagedQueryResultsConfiguration {
pub enabled: bool,
pub encryption_configuration: Option<ManagedQueryResultsEncryptionConfiguration>,
}Expand description
The configuration for storing results in Athena owned storage, which includes whether this feature is enabled; whether encryption configuration, if any, is used for encrypting query results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolIf set to true, allows you to store query results in Athena owned storage. If set to false, workgroup member stores query results in location specified under ResultConfiguration$OutputLocation. The default is false. A workgroup cannot have the ResultConfiguration$OutputLocation parameter when you set this field to true.
encryption_configuration: Option<ManagedQueryResultsEncryptionConfiguration>If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.
Implementations
Sourceimpl ManagedQueryResultsConfiguration
impl ManagedQueryResultsConfiguration
Sourcepub fn enabled(&self) -> bool
pub fn enabled(&self) -> bool
If set to true, allows you to store query results in Athena owned storage. If set to false, workgroup member stores query results in location specified under ResultConfiguration$OutputLocation. The default is false. A workgroup cannot have the ResultConfiguration$OutputLocation parameter when you set this field to true.
Sourcepub fn encryption_configuration(
&self,
) -> Option<&ManagedQueryResultsEncryptionConfiguration>
pub fn encryption_configuration( &self, ) -> Option<&ManagedQueryResultsEncryptionConfiguration>
If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.
Sourceimpl ManagedQueryResultsConfiguration
impl ManagedQueryResultsConfiguration
Sourcepub fn builder() -> ManagedQueryResultsConfigurationBuilder
pub fn builder() -> ManagedQueryResultsConfigurationBuilder
Creates a new builder-style object to manufacture ManagedQueryResultsConfiguration.