#[non_exhaustive]pub struct ManagedQueryResultsConfigurationUpdates {
pub enabled: Option<bool>,
pub encryption_configuration: Option<ManagedQueryResultsEncryptionConfiguration>,
pub remove_encryption_configuration: Option<bool>,
}Expand description
Updates the configuration for managed query results.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: Option<bool>If set to true, specifies that Athena manages query results in Athena owned storage.
encryption_configuration: Option<ManagedQueryResultsEncryptionConfiguration>If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.
remove_encryption_configuration: Option<bool>If set to true, it removes workgroup from Athena owned storage. The existing query results are cleaned up after 24hrs. You must provide query results in location specified under ResultConfiguration$OutputLocation.
Implementations
Sourceimpl ManagedQueryResultsConfigurationUpdates
impl ManagedQueryResultsConfigurationUpdates
Sourcepub fn enabled(&self) -> Option<bool>
pub fn enabled(&self) -> Option<bool>
If set to true, specifies that Athena manages query results in Athena owned storage.
Sourcepub fn encryption_configuration(
&self,
) -> Option<&ManagedQueryResultsEncryptionConfiguration>
pub fn encryption_configuration( &self, ) -> Option<&ManagedQueryResultsEncryptionConfiguration>
If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.
Sourcepub fn remove_encryption_configuration(&self) -> Option<bool>
pub fn remove_encryption_configuration(&self) -> Option<bool>
If set to true, it removes workgroup from Athena owned storage. The existing query results are cleaned up after 24hrs. You must provide query results in location specified under ResultConfiguration$OutputLocation.
Sourceimpl ManagedQueryResultsConfigurationUpdates
impl ManagedQueryResultsConfigurationUpdates
Sourcepub fn builder() -> ManagedQueryResultsConfigurationUpdatesBuilder
pub fn builder() -> ManagedQueryResultsConfigurationUpdatesBuilder
Creates a new builder-style object to manufacture ManagedQueryResultsConfigurationUpdates.