#[non_exhaustive]pub struct ManagedQueryResultsEncryptionConfiguration {
pub kms_key: String,
}Expand description
If you encrypt query and calculation results in Athena owned storage, this field indicates the encryption option (for example, SSE_KMS or CSE_KMS) and key information.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key: StringThe ARN of an KMS key for encrypting managed query results.
Implementations
Sourceimpl ManagedQueryResultsEncryptionConfiguration
impl ManagedQueryResultsEncryptionConfiguration
Sourcepub fn builder() -> ManagedQueryResultsEncryptionConfigurationBuilder
pub fn builder() -> ManagedQueryResultsEncryptionConfigurationBuilder
Creates a new builder-style object to manufacture ManagedQueryResultsEncryptionConfiguration.