#[non_exhaustive]pub struct ResultReuseInformation {
pub reused_previous_result: bool,
}Expand description
Contains information about whether the result of a previous query was reused.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reused_previous_result: boolTrue if a previous query result was reused; false if the result was generated from a new run of the query.
Implementations
Sourceimpl ResultReuseInformation
impl ResultReuseInformation
Sourcepub fn reused_previous_result(&self) -> bool
pub fn reused_previous_result(&self) -> bool
True if a previous query result was reused; false if the result was generated from a new run of the query.
Sourceimpl ResultReuseInformation
impl ResultReuseInformation
Sourcepub fn builder() -> ResultReuseInformationBuilder
pub fn builder() -> ResultReuseInformationBuilder
Creates a new builder-style object to manufacture ResultReuseInformation.