#[non_exhaustive]pub struct ResultSet {
pub rows: Option<Vec<Row>>,
pub result_set_metadata: Option<ResultSetMetadata>,
}Expand description
The metadata and rows that make up a query result set. The metadata describes the column structure and data types. To return a ResultSet object, use GetQueryResults.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rows: Option<Vec<Row>>The rows in the table.
result_set_metadata: Option<ResultSetMetadata>The metadata that describes the column structure and data types of a table of query results.
Implementations
Sourceimpl ResultSet
impl ResultSet
Sourcepub fn rows(&self) -> &[Row]
pub fn rows(&self) -> &[Row]
The rows in the table.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .rows.is_none().
Sourcepub fn result_set_metadata(&self) -> Option<&ResultSetMetadata>
pub fn result_set_metadata(&self) -> Option<&ResultSetMetadata>
The metadata that describes the column structure and data types of a table of query results.