#[non_exhaustive]pub struct ResultSetMetadata {
pub column_info: Option<Vec<ColumnInfo>>,
}Expand description
The metadata that describes the column structure and data types of a table of query results. To return a ResultSetMetadata object, use GetQueryResults.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.column_info: Option<Vec<ColumnInfo>>Information about the columns returned in a query result metadata.
Implementations
Sourceimpl ResultSetMetadata
impl ResultSetMetadata
Sourcepub fn column_info(&self) -> &[ColumnInfo]
pub fn column_info(&self) -> &[ColumnInfo]
Information about the columns returned in a query result metadata.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .column_info.is_none().
Sourceimpl ResultSetMetadata
impl ResultSetMetadata
Sourcepub fn builder() -> ResultSetMetadataBuilder
pub fn builder() -> ResultSetMetadataBuilder
Creates a new builder-style object to manufacture ResultSetMetadata.