#[non_exhaustive]pub struct UnprocessedQueryExecutionId {
pub query_execution_id: Option<String>,
pub error_code: Option<String>,
pub error_message: Option<String>,
}Expand description
Describes a query execution that failed to process.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_execution_id: Option<String>The unique identifier of the query execution.
error_code: Option<String>The error code returned when the query execution failed to process, if applicable.
error_message: Option<String>The error message returned when the query execution failed to process, if applicable.
Implementations
Sourceimpl UnprocessedQueryExecutionId
impl UnprocessedQueryExecutionId
Sourcepub fn query_execution_id(&self) -> Option<&str>
pub fn query_execution_id(&self) -> Option<&str>
The unique identifier of the query execution.
Sourcepub fn error_code(&self) -> Option<&str>
pub fn error_code(&self) -> Option<&str>
The error code returned when the query execution failed to process, if applicable.
Sourcepub fn error_message(&self) -> Option<&str>
pub fn error_message(&self) -> Option<&str>
The error message returned when the query execution failed to process, if applicable.
Sourceimpl UnprocessedQueryExecutionId
impl UnprocessedQueryExecutionId
Sourcepub fn builder() -> UnprocessedQueryExecutionIdBuilder
pub fn builder() -> UnprocessedQueryExecutionIdBuilder
Creates a new builder-style object to manufacture UnprocessedQueryExecutionId.