#[non_exhaustive]pub struct WorkGroupSummary {
pub name: Option<String>,
pub state: Option<WorkGroupState>,
pub description: Option<String>,
pub creation_time: Option<DateTime>,
pub engine_version: Option<EngineVersion>,
pub identity_center_application_arn: Option<String>,
}Expand description
The summary information for the workgroup, which includes its name, state, description, and the date and time it was created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the workgroup.
state: Option<WorkGroupState>The state of the workgroup.
description: Option<String>The workgroup description.
creation_time: Option<DateTime>The workgroup creation date and time.
engine_version: Option<EngineVersion>The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
identity_center_application_arn: Option<String>The ARN of the IAM Identity Center enabled application associated with the workgroup.
Implementations
Sourceimpl WorkGroupSummary
impl WorkGroupSummary
Sourcepub fn state(&self) -> Option<&WorkGroupState>
pub fn state(&self) -> Option<&WorkGroupState>
The state of the workgroup.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The workgroup description.
Sourcepub fn creation_time(&self) -> Option<&DateTime>
pub fn creation_time(&self) -> Option<&DateTime>
The workgroup creation date and time.
Sourcepub fn engine_version(&self) -> Option<&EngineVersion>
pub fn engine_version(&self) -> Option<&EngineVersion>
The engine version setting for all queries on the workgroup. Queries on the AmazonAthenaPreviewFunctionality workgroup run on the preview engine regardless of this setting.
Sourcepub fn identity_center_application_arn(&self) -> Option<&str>
pub fn identity_center_application_arn(&self) -> Option<&str>
The ARN of the IAM Identity Center enabled application associated with the workgroup.
Sourceimpl WorkGroupSummary
impl WorkGroupSummary
Sourcepub fn builder() -> WorkGroupSummaryBuilder
pub fn builder() -> WorkGroupSummaryBuilder
Creates a new builder-style object to manufacture WorkGroupSummary.