#[non_exhaustive]pub struct ColumnInfo {
pub catalog_name: Option<String>,
pub schema_name: Option<String>,
pub table_name: Option<String>,
pub name: String,
pub label: Option<String>,
pub type: String,
pub precision: i32,
pub scale: i32,
pub nullable: Option<ColumnNullable>,
pub case_sensitive: bool,
}Expand description
Information about the columns in a query execution result.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_name: Option<String>The catalog to which the query results belong.
schema_name: Option<String>The schema name (database name) to which the query results belong.
table_name: Option<String>The table name for the query results.
name: StringThe name of the column.
label: Option<String>A column label.
type: StringThe data type of the column.
precision: i32For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.
scale: i32For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.
nullable: Option<ColumnNullable>Unsupported constraint. This value always shows as UNKNOWN.
case_sensitive: boolIndicates whether values in the column are case-sensitive.
Implementations
Sourceimpl ColumnInfo
impl ColumnInfo
Sourcepub fn catalog_name(&self) -> Option<&str>
pub fn catalog_name(&self) -> Option<&str>
The catalog to which the query results belong.
Sourcepub fn schema_name(&self) -> Option<&str>
pub fn schema_name(&self) -> Option<&str>
The schema name (database name) to which the query results belong.
Sourcepub fn table_name(&self) -> Option<&str>
pub fn table_name(&self) -> Option<&str>
The table name for the query results.
Sourcepub fn precision(&self) -> i32
pub fn precision(&self) -> i32
For DECIMAL data types, specifies the total number of digits, up to 38. For performance reasons, we recommend up to 18 digits.
Sourcepub fn scale(&self) -> i32
pub fn scale(&self) -> i32
For DECIMAL data types, specifies the total number of digits in the fractional part of the value. Defaults to 0.
Sourcepub fn nullable(&self) -> Option<&ColumnNullable>
pub fn nullable(&self) -> Option<&ColumnNullable>
Unsupported constraint. This value always shows as UNKNOWN.
Sourcepub fn case_sensitive(&self) -> bool
pub fn case_sensitive(&self) -> bool
Indicates whether values in the column are case-sensitive.
Sourceimpl ColumnInfo
impl ColumnInfo
Sourcepub fn builder() -> ColumnInfoBuilder
pub fn builder() -> ColumnInfoBuilder
Creates a new builder-style object to manufacture ColumnInfo.