#[non_exhaustive]pub struct DataCatalogSummary {
pub catalog_name: Option<String>,
pub type: Option<DataCatalogType>,
pub status: Option<DataCatalogStatus>,
pub connection_type: Option<ConnectionType>,
pub error: Option<String>,
}Expand description
The summary information for the data catalog, which includes its name and type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.catalog_name: Option<String>The name of the data catalog. The catalog name is unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
type: Option<DataCatalogType>The data catalog type.
status: Option<DataCatalogStatus>The status of the creation or deletion of the data catalog.
-
The
LAMBDA,GLUE, andHIVEdata catalog types are created synchronously. Their status is eitherCREATE_COMPLETEorCREATE_FAILED. -
The
FEDERATEDdata catalog type is created asynchronously.
Data catalog creation status:
-
CREATE_IN_PROGRESS: Federated data catalog creation in progress. -
CREATE_COMPLETE: Data catalog creation complete. -
CREATE_FAILED: Data catalog could not be created. -
CREATE_FAILED_CLEANUP_IN_PROGRESS: Federated data catalog creation failed and is being removed. -
CREATE_FAILED_CLEANUP_COMPLETE: Federated data catalog creation failed and was removed. -
CREATE_FAILED_CLEANUP_FAILED: Federated data catalog creation failed but could not be removed.
Data catalog deletion status:
-
DELETE_IN_PROGRESS: Federated data catalog deletion in progress. -
DELETE_COMPLETE: Federated data catalog deleted. -
DELETE_FAILED: Federated data catalog could not be deleted.
connection_type: Option<ConnectionType>The type of connection for a FEDERATED data catalog (for example, REDSHIFT, MYSQL, or SQLSERVER). For information about individual connectors, see Available data source connectors.
error: Option<String>Text of the error that occurred during data catalog creation or deletion.
Implementations
Sourceimpl DataCatalogSummary
impl DataCatalogSummary
Sourcepub fn catalog_name(&self) -> Option<&str>
pub fn catalog_name(&self) -> Option<&str>
The name of the data catalog. The catalog name is unique for the Amazon Web Services account and can use a maximum of 127 alphanumeric, underscore, at sign, or hyphen characters. The remainder of the length constraint of 256 is reserved for use by Athena.
Sourcepub fn type(&self) -> Option<&DataCatalogType>
pub fn type(&self) -> Option<&DataCatalogType>
The data catalog type.
Sourcepub fn status(&self) -> Option<&DataCatalogStatus>
pub fn status(&self) -> Option<&DataCatalogStatus>
The status of the creation or deletion of the data catalog.
-
The
LAMBDA,GLUE, andHIVEdata catalog types are created synchronously. Their status is eitherCREATE_COMPLETEorCREATE_FAILED. -
The
FEDERATEDdata catalog type is created asynchronously.
Data catalog creation status:
-
CREATE_IN_PROGRESS: Federated data catalog creation in progress. -
CREATE_COMPLETE: Data catalog creation complete. -
CREATE_FAILED: Data catalog could not be created. -
CREATE_FAILED_CLEANUP_IN_PROGRESS: Federated data catalog creation failed and is being removed. -
CREATE_FAILED_CLEANUP_COMPLETE: Federated data catalog creation failed and was removed. -
CREATE_FAILED_CLEANUP_FAILED: Federated data catalog creation failed but could not be removed.
Data catalog deletion status:
-
DELETE_IN_PROGRESS: Federated data catalog deletion in progress. -
DELETE_COMPLETE: Federated data catalog deleted. -
DELETE_FAILED: Federated data catalog could not be deleted.
Sourcepub fn connection_type(&self) -> Option<&ConnectionType>
pub fn connection_type(&self) -> Option<&ConnectionType>
The type of connection for a FEDERATED data catalog (for example, REDSHIFT, MYSQL, or SQLSERVER). For information about individual connectors, see Available data source connectors.
Sourceimpl DataCatalogSummary
impl DataCatalogSummary
Sourcepub fn builder() -> DataCatalogSummaryBuilder
pub fn builder() -> DataCatalogSummaryBuilder
Creates a new builder-style object to manufacture DataCatalogSummary.