#[non_exhaustive]pub struct ExecutorsSummary {
pub executor_id: String,
pub executor_type: Option<ExecutorType>,
pub start_date_time: Option<i64>,
pub termination_date_time: Option<i64>,
pub executor_state: Option<ExecutorState>,
pub executor_size: Option<i64>,
}Expand description
Contains summary information about an executor.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.executor_id: StringThe UUID of the executor.
executor_type: Option<ExecutorType>The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).
start_date_time: Option<i64>The date and time that the executor started.
termination_date_time: Option<i64>The date and time that the executor was terminated.
executor_state: Option<ExecutorState>The processing state of the executor. A description of each state follows.
CREATING - The executor is being started, including acquiring resources.
CREATED - The executor has been started.
REGISTERED - The executor has been registered.
TERMINATING - The executor is in the process of shutting down.
TERMINATED - The executor is no longer running.
FAILED - Due to a failure, the executor is no longer running.
executor_size: Option<i64>The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.
Implementations
Sourceimpl ExecutorsSummary
impl ExecutorsSummary
Sourcepub fn executor_id(&self) -> &str
pub fn executor_id(&self) -> &str
The UUID of the executor.
Sourcepub fn executor_type(&self) -> Option<&ExecutorType>
pub fn executor_type(&self) -> Option<&ExecutorType>
The type of executor used for the application (COORDINATOR, GATEWAY, or WORKER).
Sourcepub fn start_date_time(&self) -> Option<i64>
pub fn start_date_time(&self) -> Option<i64>
The date and time that the executor started.
Sourcepub fn termination_date_time(&self) -> Option<i64>
pub fn termination_date_time(&self) -> Option<i64>
The date and time that the executor was terminated.
Sourcepub fn executor_state(&self) -> Option<&ExecutorState>
pub fn executor_state(&self) -> Option<&ExecutorState>
The processing state of the executor. A description of each state follows.
CREATING - The executor is being started, including acquiring resources.
CREATED - The executor has been started.
REGISTERED - The executor has been registered.
TERMINATING - The executor is in the process of shutting down.
TERMINATED - The executor is no longer running.
FAILED - Due to a failure, the executor is no longer running.
Sourcepub fn executor_size(&self) -> Option<i64>
pub fn executor_size(&self) -> Option<i64>
The smallest unit of compute that a session can request from Athena. Size is measured in data processing unit (DPU) values, a relative measure of processing power.
Sourceimpl ExecutorsSummary
impl ExecutorsSummary
Sourcepub fn builder() -> ExecutorsSummaryBuilder
pub fn builder() -> ExecutorsSummaryBuilder
Creates a new builder-style object to manufacture ExecutorsSummary.